.onLoad <- function(libname, pkgname) {

	# default to print date-time stamp
	options(filenamer.timestamp=2);

	# default to print date stamp for path
	options(filenamer.path.timestamp=1);

}
